# ---------------------------------------------
# Formant analysis
# PRAAT script 
# Pascal Gaillard 2012
# pascal.gaillard@univ-tlse2.fr
# version 1.0 (sept 20012)
# ---------------------------------------------
# Output : PDF or EPS file

soundname$ = selected$("Sound")

# --------------- Parameters
form Formant parameters
#	sentence analysistitle sound name
	sentence analysis_output_directory /Users/pgaillar/Dropbox/Perc_Cyntia/Analyses_6-09-2012/Analyses_voyelle_seule/
	optionmenu save_table_analysis: 2
		option No
		option Yes
	optionmenu scatter_plot: 1
		option F1 F2
		option F1 F3
		option F2 F3
	optionmenu type_of_image: 4
		option Image (copy to clipboard)
		option Vectoriel (copy to clipboard)
		option PostScript (write on disk)
		option PDF (write on disk)
#	integer scatter_vertical_formant 1
#	integer scatter_horizontal_formant 2

endform

#########################
# PostScript settings... yes finest automatic yes
#########################


# -----------------default analysis parameters
time_step = 0.0
max_number_formant = 5
max_formant = 5500
window_length = 0.025
preemphasis = 50

# -----------------default display parameters
timer_begin = 0.0
timer_end = 0.0
max_freq = 5500

# ----------------read the selected filename
soundname$ = selected$("Sound")

# ----------------read the total duration and sampling frequency of the sound
	select Sound 'soundname$'
	total_duration = Get total duration
	sampling_frequency = Get sampling frequency

# ----------------erase praat picture screen
	Erase all


# ----------------set the font and color
	Times
	Font size... 10
	Black
	Line width... 0.5

# ---------------- waveform
# Define size and position of waveform (by specifying grid coordinates)

	select Sound 'soundname$'
	Viewport... 0 6 0 2
	Maroon
	Draw... 0 0 0 0 yes curve
	
# ----------------waveform labels creation
	# Label x axis 
	# Text bottom... yes 'x_axis_label$' 
	Marks bottom every... 1 0.1 yes yes yes
	# Draw inner box
 

#----------------formant analysis
select Sound 'soundname$'
To Formant (burg)... time_step max_number_formant max_formant window_length preemphasis
formantname$ = selected$("Formant")

select Formant 'formantname$'
Down to Table... no yes 2 no 3 no 2 no
tablename$ = selected$("Table")

# ----------------formant display
select Formant 'formantname$'
Viewport... 0 6 2 5
Speckle... timer_begin timer_end max_freq 30 yes
Marks bottom every... 1 0.1 yes yes yes

Viewport... 0 6 5 8
Draw tracks... timer_begin timer_end max_freq  yes
Marks bottom every... 1 0.1 yes yes yes

Viewport... 6 12 2 8

if scatter_plot$ = "F1 F2"
  scatter_vertical_formant = 1
  scatter_horizontal_formant = 2
  Scatter plot... timer_begin timer_end scatter_horizontal_formant 400 3000 scatter_vertical_formant 1500 100 1.0 yes +
endif

if scatter_plot$ = "F1 F3"
  scatter_vertical_formant = 1
  scatter_horizontal_formant = 3
  Scatter plot... timer_begin timer_end scatter_horizontal_formant 2000 4600 scatter_vertical_formant 1500 100 1.0 yes +
endif

if scatter_plot$ = "F2 F3"
  scatter_vertical_formant = 2
  scatter_horizontal_formant = 3
  Scatter plot... timer_begin timer_end scatter_horizontal_formant 2000 4600 scatter_vertical_formant 400 3000 1.0 yes +
endif


Marks left every... 1 100 yes yes yes
Marks bottom every... 1 200 yes yes yes

# ----------------write title and informations

Font size... 18

Viewport... 7 7.5 0.35 0.5
Maroon
Text... 0 Left 0 top Formant Analysis of

Viewport... 7 7.5 0.5 1
Maroon
# Text top... no Sound object : 'soundname$' 
Text... 0 Left 0 top sound object : 'soundname$' 


Font size... 12
Black


Viewport... 7 7.5 1 1.25
Text... 0 Left 0 top Sampling frequency : 
Viewport... 7 7.5 1.25 1.5
Text... 0 Left 0 top Total duration: 
#Viewport... 6.5 6.75 6.5 6.75
#Text... 0 Left 0 top Centre of gravity :
#Viewport... 6.5 6.75 6.75 7
#Text... 0 Left 0 top Standard deviation :

Viewport... 9 10 1 1.25
Text... 0 Left 0 top 'sampling_frequency' Hz
Viewport... 9 10 1.25 1.5
Text... 0 Left 0 top 'total_duration:2' s
#Viewport... 8.5 8.75 6.5 6.75
#Text... 0 Left 0 top 'centregravity' Hz
#Viewport... 8.5 8.75 6.75 7
#Text... 0 Left 0 top 'standarddev' Hz

Font size... 10
Black

Maroon
# ----------------labels on each figure
	Select outer viewport... 5 5.5 0 0.4
	Text... 0 Right 0 Top  Waveform
	Select outer viewport... 5 5.5 2 2.4
	Text... 0 Right 0 Top  Speckle
	Select outer viewport... 5 5.5 5 5.4
	Text... 0 Right 0 Top  Tracks
	Select outer viewport... 11.5 11 2 2.4
	Text... 0 Right 0 Top  Scatter plot
Black



# ------------ save table
select Table 'tablename$'
if save_table_analysis$ = "Yes"
	select Table 'tablename$'
	Save as tab-separated file... 'analysis_output_directory$''soundname$'.xls
	echo Excel file (tab-separated format) "'soundname$'.xls" was written into " 'analysis_output_directory$' " directory
endif

# ------------ copy to
	Viewport... 0 12 0 8
	if type_of_image$	= "Image (copy to clipboard)"
		Copy screen image to clipboard
		# echo Screen image is in the clipboard
	endif	
	if type_of_image$	= "Vectoriel (copy to clipboard)"
		Copy to clipboard
		# echo Vectored draw is in the clipboard
	endif	
	if type_of_image$	= "PostScript (write on disk)"
		Write to EPS file... 'analysis_output_directory$''soundname$'-fmtanalyse.eps
		echo File "'soundname$'-fmtanalyse.eps" was written into into " 'analysis_output_directory$' " directory
	endif	
	if type_of_image$	= "PDF (write on disk)"
		Write to PDF file... 'analysis_output_directory$''soundname$'-fmtanalyse.pdf
		echo File "'soundname$'-fmtanalyse.pdf" was written into into " 'analysis_output_directory$' " directory
	endif	
		
# ------------  remove
	select Formant 'formantname$'
	Remove
	select Table 'tablename$'
	Remove
	select Sound 'soundname$'
